@@ -39,12 +39,17 @@
 #include <process.h>
 #include <winsock2.h>
 #endif
-#include <QActionEvent>
 #include <QTimer>
 #include <stdlib.h>
 #if KWINDOWSYSTEM_HAVE_X11
 #include <netwm.h>
-#include <qx11info_x11.h>
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <private/qtx11extras_p.h>
+#else
+#include <QX11Info>
+#endif
+
 #endif
 #include <QCoreApplication>
 #include <QDebug>
@@ -54,11 +59,13 @@
 #include <X11/Xlib.h>
 #include <fixx11h.h>
 #include <kwindowsystem.h>
+#include <kx11extras.h>
 #include <kxmessages.h>
 #endif
 
+#if KWINDOWSYSTEM_HAVE_X11
 static const char NET_STARTUP_MSG[] = "_NET_STARTUP_INFO";
-static const char NET_STARTUP_WINDOW[] = "_NET_STARTUP_ID";
+#endif
 // DESKTOP_STARTUP_ID is used also in kinit/wrapper.c ,
 // kdesu in both kdelibs and kdebase and who knows where else
 static const char NET_STARTUP_ENV[] = "DESKTOP_STARTUP_ID";
@@ -171,8 +178,8 @@ public:
     QTimer *cleanup;
     int flags;
 
-    Private(int flags_P, KStartupInfo *q)
-        : q(q)
+    Private(int flags_P, KStartupInfo *qq)
+        : q(qq)
         , timeout(60)
 #if KWINDOWSYSTEM_HAVE_X11
         , msgs(NET_STARTUP_MSG)
@@ -772,12 +779,12 @@ void KStartupInfo::setNewStartupId(QWindow *window, const QByteArray &startup_id
             }
         }
         if (activate) {
-            KWindowSystem::setOnDesktop(window->winId(), KWindowSystem::currentDesktop());
+            KX11Extras::setOnDesktop(window->winId(), KX11Extras::currentDesktop());
             // This is not very nice, but there's no way how to get any
             // usable timestamp without ASN, so force activating the window.
             // And even with ASN, it's not possible to get the timestamp here,
             // so if the WM doesn't have support for ASN, it can't be used either.
-            KWindowSystem::forceActiveWindow(window->winId());
+            KX11Extras::forceActiveWindow(window->winId());
         }
     }
 #else
@@ -1215,8 +1222,9 @@ QString KStartupInfoData::Private::to_text() const
     if (!icon.isEmpty()) {
         ret += QStringLiteral(" ICON=\"%1\"").arg(icon);
     }
-    if (desktop != 0)
+    if (desktop != 0) {
         ret += QStringLiteral(" DESKTOP=%1").arg(desktop == NET::OnAllDesktops ? NET::OnAllDesktops : desktop - 1); // spec counts from 0
+    }
     if (!wmclass.isEmpty()) {
         ret += QStringLiteral(" WMCLASS=\"%1\"").arg(QString(wmclass));
     }
@@ -1261,8 +1269,9 @@ KStartupInfoData::KStartupInfoData(const QString &txt_P)
             d->icon = get_str(*it);
         } else if ((*it).startsWith(QLatin1String("DESKTOP="))) {
             d->desktop = get_num(*it);
-            if (d->desktop != NET::OnAllDesktops)
+            if (d->desktop != NET::OnAllDesktops) {
                 ++d->desktop; // spec counts from 0
+            }
         } else if ((*it).startsWith(QLatin1String("WMCLASS="))) {
             d->wmclass = get_cstr(*it);
         } else if ((*it).startsWith(QLatin1String("HOSTNAME="))) { // added to version 1 (2014)
